%macro pmfine(lib,styear,endyear,flag,vname,userid,userpasswd);
*       This macro pulls raw data from AQS, pulls and assimilates       *;
*       sampling frequency info from AQS, and computes data capture     *;
*       rates, means, and 98th percentiles                              *;
*           lib     :   A sas libname designation                       *;
*           styear  :   start year for the retrieval                    *;
*           endyear :   end year for the retrieval                      *;
*                       Note: 3 year period required, styear >= 1999    *;
*           flag    :   y to include flags with data & n for no flags   *;
*                       with data                                       *;
*           vname   :   assigns a name to the actual concentration      *;
*                       values (for raw data saves)                     *;

%if &styear ge 1999 and %eval(&endyear-&styear)=2 %then %do;

*PART 1 - PULL RAW DATA;

%let sd=01-JAN-&styear;
%let ed=31-DEC-&endyear;

/*proc sql;
     connect to oracle (user=&userid password=&userpasswd path="aqsprod" buffsize=100);
     create table temp as
     select * from connection to oracle (
select  sites.cc_cn_stt_state_code||sites.cc_cn_county_code||sites.site_id as site,
        monitors.poc as poc,
        current_data.sampling_begin_datetime as datetime,
        protocols.sm_methodology_code as meth,
%if %upcase(&flag) eq Y %then  %do;
        qualifier_details.qu_qualifier_code as flag,
%end;
 		current_data.REPORTED_sample_value as &vname, current_data.epa_concurrence_ind as concurr
        from    monitors monitors,
        monitor_protocols monitor_protocols,
        protocols protocols,
%if %upcase(&flag) eq Y %then %do;
        qualifier_details qualifier_details,
%end;
        current_data current_data,
        sites sites
where   monitors.mo_id = monitor_protocols.mo_mo_id and
        protocols.pro_id = monitor_protocols.pro_pro_id and
        monitor_protocols.mo_mo_id = current_data.mp_mo_mo_id and
        monitor_protocols.mp_id = current_data.mp_mp_id and
%if %upcase(&flag) eq Y %then %do;
        current_data.rd_id = qualifier_details.rd_rd_id(+) and
%end;
        sites.si_id = monitors.si_si_id and
        sites.cc_cn_stt_state_code <> 'CC' and
        sites.cc_cn_stt_state_code <> '80' and
        protocols.sd_duration_code = '7' and
        monitors.pa_parameter_code = '88101' and
        upper(current_data.status_ind) = upper('p') and
        current_data.sampling_begin_datetime >= %unquote(%str(%'&sd%')) and
        current_data.sampling_begin_datetime <= %unquote(%str(%'&ed%'))
order by 1, 2, 3
);
%put &sqlxrc; *debug sql;
%put &sqlxmsg; *debug sql;
disconnect from oracle;
quit;


data temp2;
set temp;
zdate=datepart(datetime);
hr=hour(datetime);
year=year(zdate);
if year lt 2002 and site='530330033' and poc=1 then do; site='530332004'; poc=2; end;
if year lt 2002 and site='160170001' and poc=1 then do; site='160170004'; poc=4; end;
if site = '011030010' then site='011030011';
if site = '050010001' then site='050010011';
if site = '050010010' then site='050010011';
if site = '050030003' then site='050030005';
if site = '050030004' then site='050030005';
if site = '051190003' then site='051191004';
if site = '050690005' then site='050690006';
if site = '051390004' then site='051390006';
if site = '051390005' then site='051390006';
if site='180190005' then site='180190006';
if site='181570007' then site='181570008';
if site='370810009' then do; site='370810013'; poc=2; end;
if site='470370023' and poc=1 and zdate gt mdy(9,4,2002) and zdate le mdy(5,1,2003) then delete;
if site='470370025' and poc=1 and zdate gt mdy(6,6,2002) and zdate le mdy(5,1,2003) then delete;
if site='470370036' and poc=1 and zdate gt mdy(6,5,2002) and zdate le mdy(5,1,2003) then delete;
drop datetime;
format zdate mmddyy10.; 
run;

proc sort; by site poc zdate;

data tempraw (keep= site st cou poc zdate v f1-f10 ndat q meth hr concurr);
length f1-f10 $1. flag $2.;
array f(10) f1-f10;
retain n f1-f10;
set temp2; by site poc zdate;
st=substr(site,1,2);
cou=substr(site,3,3);
q=qtr(zdate);
v=round(v-.049999,.1);
if first.zdate then do;
n=0;
f1=' '; f2=' '; f3=' '; f4=' '; f5=' '; f6=' '; f7=' '; f8=' '; f9=' '; f10=' ';
end;
n+1;
if v = . then ndat=flag;
else if flag ne ' ' and v ne . then f(n)=flag;
if last.zdate then output;



data &lib..PM25_y&styear&endyear.d&sysdate.raw; set tempraw; 
*/
data tempraw; set y.Pm25_y20012003d12jul04raw;
if f1 in ('A' 'B' 'C' 'D' 'E' 'F' 'G' 'H' 'I' 'J' 'K' 'L' 'M' 'N' 'O' 'P' 'Q' 'R' 'S' 'U') then flag_f=f1;
else if  f2 in ('A' 'B' 'C' 'D' 'E' 'F' 'G' 'H' 'I' 'J' 'K' 'L' 'M' 'N' 'O' 'P' 'Q' 'R' 'S' 'U') then flag_f=f2;

*PART 2 - PULL SAMPLING FREQUENCY INFORMATION;
proc sql; create table mon as select distinct MO_ID,SI_SI_ID AS SI_ID,
PA_PARAMETER_CODE AS PARM,POC from
aqs.MONITORS where parm='88101' order by mo_id;

proc sql; create table begend as select distinct MO_mo_ID as mo_id,
min(sampling_begin_date) as beg, sampling_begin_date as beg2 ,sampling_end_date as end from 
aqs.sample_periods group by mo_id;
data begend; set begend;
format beg beg2 end datetime7.;
run;
proc sort; by mo_id beg2;
data begend2; set begend; by mo_id beg2;
if last.mo_id;
run;

proc sql; create table freq as select distinct MO_mo_ID as mo_id, REQ_COLL_FREQ_BEGIN_DATE as sf_beg,
REQ_COLL_FREQ_END_DATE as sf_en, cf_coll_freq_code as sf, RCF_ID FROM
aqs.req_coll_frequencies;
CREATE TABLE SEASCHED AS SELECT DISTINCT mo_id,SAMPLE_SCHEDULE_MONTH AS MONTH, 
max(CF_COLL_FREQ_CODE) AS SFmo from aqs.sample_schedules a, freq b where a.rcf_rcf_id=b.rcf_id and 
sf='S' group by mo_id, MONTH; quit;
data seasched;
set seasched;
momo='mo'||compress(put(month,2.0));
proc transpose data=seasched out=trantest;
by mo_id;
var sfmo;
id momo;
run;


proc sort; by mo_id;
data mons; merge mon begend2 freq trantest; by mo_id;
if parm ne ' ';
run;
proc sort; by si_id;

proc sql; create table sites as select distinct SI_ID,
cc_cn_stt_state_code as st, cc_cn_county_code as cou, site_latitude as lat, 
site_longitude as long, cc_ci_city_code as city, site_id as id from aqs.sites; 
data sites2 (keep=site si_id lat long city); set sites;
site=st||cou||id;

proc sort; by si_id;
data a;
merge mons sites2; by si_id;
mon_begin=datepart(beg);
mon_end=datepart(end);
if parm ne ' ';

proc sql; create table meta as select distinct site,poc,lat,long,city,mon_begin,mon_end
from a;
quit;

data it (keep = site poc mo_id freq q sea); 
set a;
if sf not in ('1' '3' '6' 'S') then delete;
sf_begin=datepart(sf_beg);
sf_end=datepart(sf_en);
sfbq=qtr(sf_begin);
sfeq=qtr(sf_end);
if year(sf_end) lt &styear and sf_end ne . then delete;
if year(sf_begin) gt &endyear then delete;
/*if year(sf_begin) lt &styear then sfbq=1;
if year(sf_begin)=%eval(&styear+1) then do; sfbq=sfbq+4; end;
if year(sf_end)=%eval(&styear+1) then do; sfeq=sfeq+4; end;
if year(sf_begin)=%eval(&styear+2) then do; sfbq=sfbq+8; end;
if year(sf_end)=%eval(&styear+2) then do; sfeq=sfeq+8; end;
if year(sf_end) gt &endyear or sf_end=. then sfeq=12;*/
if year(sf_begin) le &styear then sfbq=1;
if year(sf_begin)=%eval(&styear+1) then do; sfbq=5; end;
if year(sf_end)=%eval(&styear+1) then do; sfeq=sfeq+4; end;
if year(sf_begin)=%eval(&styear+2) then do; sfbq=9; end;
if year(sf_end)=%eval(&styear+2) then do; sfeq=sfeq+8; end;
if year(sf_end) gt &endyear or sf_end=. then sfeq=12;

format sf_begin sf_end mmddyy10.;

if sf='S' then do q=sfbq to sfeq;
sea=1;
	if q in (1 5 9) then do; freq=max(of mo1, mo2, mo3); output; end;
	else if q in (2 6 10) then do; freq=max(of mo4, mo5, mo6); output; end;
	else if q in (3 7 11) then do; freq=max(of mo7, mo8, mo9); output; end;
	else if q in (4 8 12) then do; freq=max(of mo10, mo11, mo12); output; end;
end;
else do q=sfbq to sfeq;
freq=sf+0; 
output;
end;
run;

proc sql; create table sf as select distinct site,poc,q,mo_id,max(freq) as freq,
max(sea) as seasonal from it group by site,poc,mo_id,q; quit;
data sf; set sf;
if q in (1 2 3 4) then year= &styear;
else if q in (5 6 7 8) then do;
year=%eval(&styear+1);
q=q-4;
end;
else do;
year=&endyear;
q=q-8;
end;


data allq;
do year = &styear to &endyear;
do q=1 to 4;
output;
end;
end;

proc sql; create table miss as select distinct site,poc,max(freq) as submiss from it group by site,poc;
create table allqmiss as select distinct * from miss, allq;
run;
proc sort data =allqmiss; by site poc year q;
proc sort data =sf; by site poc year q;
data freqs; merge allqmiss sf; by site poc year q;
if freq=. then freq=submiss;
sf=freq;
if site='160170004' and year lt 2002 then sf=3;
drop mo_id submiss freq;
run;

*PART 3 - CALCULATIONS: COMPLETENESS, MEANS, P8TH PERCENTILES;

*Get rid of non-FRM data;
data temp3yr; set tempraw;
if meth in (116 117 118 119 120 123 142 143 144 145);
year=year(zdate);
if year ge &styear and year le &endyear;
if v ne .;


*Add collocated data to primary monitor;
proc sql; create table sitepoc as select distinct site,poc from temp3yr;
proc sort; by site poc;
data prim; set sitepoc; by site poc;
if first.site;
pocprim=poc;
drop poc;
proc sort; by site;
proc sort data =temp3yr; by site;
data temp2; merge temp3yr prim; by site;
proc sort; by site zdate poc;
data temp; set temp2; by site zdate poc;
if first.zdate;
p2=poc;
poc=pocprim;
drop pocprim;
run;

data &lib..Pm25d&sysdate.colo; set temp; 

run;

%do runyr= &styear %to &endyear;

%put ***year=&runyr***;
data pm;
set temp;
if year=&runyr;
run;

data sf; set freqs;
if year=&runyr;
run;
proc sort; by site poc q;

PROC SORT data=pm; BY SITE POC zdate;


proc sort; by site poc q;

*creates yearly sampling schedule;
data sched (keep= zdate q d);
 format zdate mmddyy10.;
 dayb=mdy(1,1,&runyr);
 daye=mdy(12,31,&runyr);
 do zdate = dayb to daye;
q=qtr(zdate);
mod3=mod(zdate,3);
mod6=mod(zdate,6);
if mod6=0 then d=6;
else if mod3=0 then d=3;
else d=1;
output;
end;
run;

*Get counts of each d for completeness denominator;
proc sql; create table ct1 as select distinct q,count(*) as denom1 from sched group by q; 
create table ct3 as select distinct q,count(*) as denom3 from sched where d in (3 6) group by q; 
create table ct6 as select distinct q,count(*) as denom6 from sched where d =6 group by q;
data denom; merge ct1 ct3 ct6; by q;
run;

proc sql; create table sites as select distinct site,poc from
PM; quit;

*Cartesian join to get all sitepocs for every day;
proc sql;
CREATE TABLE speday as SELECT DISTINCT SITE,POC,ZDATE,D FROM
 sites, sched oRDER BY SITE, POC, ZDATE;

*Matches the complete possible year to the reported. Need to know d;
DATA MERGE2;
  MERGE speday pm;
  BY SITE POC zdate;
Q=QTR(ZDATE);

PROC SORT; by site poc q;

*Matches the complete schedule to the Qfreq. Only keeps Qs with data;
DATA MERGE3; MERGE merge2 sf; BY SITE POC Q;
if sf=. then delete;
run;

PROC SORT; BY SITE POC Q ZDATE;
run;

*makeup logic (d=8=sched day missed);
data temp3;
 retain smu mz1 mz2 mz3 mz4;
 format d mz1 mz2 mz3 mz4 mmddyy10.;
 set MERGE3;BY SITE POC Q ZDATE;

if substr(site,1,5)='39035' and &runyr=1999 then muct=100;
else muct=5;

 if first.Q then do;
  smu=0; mz1=.;mz2=.; mz3=.; mz4=.;
 end;
 if sf=3 and (d= 3 or d=6) and v=. then
  do;
   mz4=mz3;
   mz3=mz2;
   mz2=mz1;
   mz1=zdate;
  end;


if sf=3 and d=1 and v ne . and smu lt muct
then do;
 if (zdate-mz4=7) then do; d=mz4; mz4=.; smu=smu+1; end;
 else if (zdate-mz3=7) then do; d=mz3; mz3=.; smu=smu+1; end;
 else if (zdate-mz2=7) then do; d=mz2; mz2=.; smu=smu+1; end;
 else if (zdate-mz1=7) then do; d=mz1; mz1=.; smu=smu+1; end;
 else if (zdate-mz4=1) or (zdate-mz4=2)  then do;
   d=mz4; mz4=.; smu=smu+1;
  end;
 else if (zdate-mz3=1) or (zdate-mz3=2) then do;
   d=mz3; mz3=.; smu=smu+1;
  end;
 else if (zdate-mz2=1) or (zdate-mz2=2) then do;
   d=mz2; mz2=.; smu=smu+1;
  end;
 else if (zdate-mz1=1) or (zdate-mz1=2) then do;
   d=mz1; mz1=.; smu=smu+1;
  end;
end;

 if sf=6 and (d=6) and v=. then
  do;
   mz2=mz1;
   mz1=zdate;
  end;
if sf=6 and (d=1 or d=3) and v ne . and smu lt muct then do;
 if (zdate-mz2=7) then do; d=mz2; mz2=.; smu=smu+1; end;
 else if (zdate-mz1=7) then do; d=mz1; mz1=.; smu=smu+1; end;
 else if (zdate-mz2 in (1 2 3 4 5)) and smu lt muct then do;
   d=mz2; mz2=.; smu=smu+1;
  end;
 else if (zdate-mz1 in (1 2 3 4 5)) and smu lt muct then do;
   d=mz1; mz1=.; smu=smu+1;
  end;
end;
if &runyr=2001 and site='170190004' and zdate=mdy(11,12,2001) then d=mdy(11,21,2001);
run;

data &lib..sched&runyr; set temp3;

*Get counts of each d of data;
proc sql; create table e1 as select distinct site,poc,sf,count(*)
as n1,q from temp3 where v ne . and d=1
group by site,poc,sf,q order
by site,poc,q; quit;
proc sql; create table e3 as select distinct site,poc,sf,count(*)
as n3,q from temp3 where v ne . and d=3
group by site,poc,sf,q order
by site,poc,q; quit;
proc sql; create table e6 as select distinct site,poc,sf,count(*)
as n6,q from temp3 where v ne . and d=6
group by site,poc,sf,q order
by site,poc,q; quit;
proc sql; create table ee as select distinct site,poc,sf,count(*)
as ne,q from temp3 where v ne . and d > 8
group by site,poc,sf,q order
by site,poc,q; quit;
*Counts merged by quarter;

data all; merge e1 e3 e6 ee; by site poc q;
proc sort; by q;
data all; merge all denom; by q;
if n1=. then n1=0;
 if n3=. then n3=0;
 if n6=. then n6=0;
 if ne=. then ne=0;
if sf=1 then num=n1+n3+n6+ne;
 else if sf=3 then num=n3+n6+ne;
 else if sf=6 then num=n6+ne;

if sf=1 then denom=denom1;
else if sf=3 then denom=denom3;
else denom=denom6;
proc sort; by site poc q;

proc sql; create table q1 as select distinct site, poc,sf as sf&runyr.q1,
num/denom as p&runyr.q1,num as nvalid&runyr.q1 from all where q=1; quit;
proc sql; create table q2 as select distinct site, poc,sf as sf&runyr.q2,
num/denom as p&runyr.q2,num as nvalid&runyr.q2 from all where q=2; quit;
proc sql; create table q3 as select distinct site, poc,sf as sf&runyr.q3,
num/denom as p&runyr.q3,num as nvalid&runyr.q3 from all where q=3; quit;
proc sql; create table q4 as select distinct site, poc,sf as sf&runyr.q4,
num/denom as p&runyr.q4,num as nvalid&runyr.q4 from all where q=4; quit;

*calculate means and num obs;
proc sort data=pm; by site poc q;

proc means DATA=PM noprint; by site poc q; var v;
output out=qtab N=N;
data t1;
set qtab; if q=1;

n&runyr.q1=n; 
data t2;
set qtab; if q=2;

n&runyr.q2=n; 
data t3;
set qtab; if q=3;

n&runyr.q3=n; 
data t4;
set qtab; if q=4;

n&runyr.q4=n; 
run;

DATA PM2; SET PM; *IF FLAG_F=' ';
proc means DATA=PM2 noprint; by site poc q; var v;
output out=qtab2 MEAN=MEAN;
data t1A;
set qtab2; if q=1;
mean&runyr.q1=mean; 

data t2A;
set qtab2; if q=2;
mean&runyr.q2=mean; 

data t3A;
set qtab2; if q=3;
mean&runyr.q3=mean; 

data t4A;
set qtab2; if q=4;
mean&runyr.q4=mean; 

run;


*Calculate 98th percentile - regular formula;

proc sql;
create table nonsea as select distinct site,poc,max(seasonal) as seayear,
max(sf) as sflow from sf group by site,poc;
create table cts as select distinct a.site,a.poc,a.q,min(denom,n) as an,n,denom
from qtab a, all b where a.site=b.site and a.poc=b.poc and a.q=b.q;
create table p98n as select distinct site,poc,sum(an) as an from cts group by site,poc; quit;

proc sort data=nonsea; by site poc;
proc sort data =pm; by site poc;

data pmreg (keep= site poc v an FLAG_F);
merge p98n pm nonsea; by site poc;
*if seayear=.;
/*if f1 in ('A' 'B' 'C' 'D' 'E' 'F' 'G' 'H' 'I' 'J' 'K' 'L' 'M' 'N' 'O' 'P' 'Q' 'R' 'S' 'U') then flag_f=f1;
else if  f2 in ('A' 'B' 'C' 'D' 'E' 'F' 'G' 'H' 'I' 'J' 'K' 'L' 'M' 'N' 'O' 'P' 'Q' 'R' 'S' 'U') then flag_f=f2;
IF FLAG_F EQ ' ';*/

proc sort data =pmreg; by site poc descending v;

data p98 (keep=site poc p98_&runyr an nc98) 
p95 (keep=site poc p95_&runyr an nc95)
p96 (keep=site poc p96_&runyr an nc96)
p97 (keep=site poc p97_&runyr an nc97)
p99 (keep=site poc p99_&runyr an nc99);

set pmreg;by site poc descending v;
retain nc98 nc95 nc96 nc97 nc99 np;
if first.poc then do;

nc95=an-int(.95*an);
nc96=an-int(.96*an);
nc97=an-int(.97*an);
nc98=an-int(.98*an);
nc99=an-int(.99*an);
np=0;
end;

np+1;
if np = nc98 then do;
p98_&runyr=round(v,.1);
output p98;
end;
if np = nc95 then do;
p95_&runyr=round(v,.1);
output p95;
end;
if np = nc96 then do;
p96_&runyr=round(v,.1);
output p96;
end;
if np = nc97 then do;
p97_&runyr=round(v,.1);
output p97;
end;
if np = nc99 then do;
p99_&runyr=round(v,.1);
output p99;
end;

run;


*calculate p98 for seasonal sampling sites using weighting formula;
proc sort data=merge3;
by site poc q;
run; 
data merge3; merge merge3 nonsea; by site poc;
if seayear=1;
if sf=sflow then sea1=1;
else sea2=1;
proc sql; create table ct as select site,poc,count(sea1) as dayns1,count(sea2) as dayns2 from merge3
group by site,poc;
 

data merge4; set merge3; if v ne .;
run;

data temp1;
MERGE merge4 ct; by site poc;
d1=dayns1/(dayns1+dayns2);
d2=1-d1;
DROP F1-F10;
run;

proc sort; by site poc year;
proc sql; create table n1 as select distinct site,poc,year,count(*) as n1 from
temp1 where sea1=1 group by site,poc, year;
proc sql; create table n2 as select distinct site,poc,year,count(*) as n2 from
temp1 where sea2=1 group by site,poc, year;

data temp2; merge temp1 n1 n2; by site poc year;
proc sort; by site poc year sea1 v;
data temp3;
set temp2; by site poc year sea1 v;
if first.sea1 then x=0;
x+1;
if sea1=1 then f1 =x/n1;
else f2=x/n2;

proc sort; by site poc year v; run;
data temp4;
retain pass1 pass2;
set temp3;
by site poc year v;
if n1 =. then f1=1;
if n2=. then f2=1;
if first.year then do; pass1=.; pass2=.; end;
if f1 ne . then pass1=f1;
if f1 = . then f1=pass1;
if f2 ne . then pass2=f2;
if f2 = . then f2=pass2;
w=(d1*f1) + (d2*f2);
run;
proc sort; by site poc year v; run;

data p95s (keep=site poc p95s);
set temp4; by site poc v;
if first.poc then n=0;
if w gt .95 then n+1;
if n=1 then do; 
p95s=v;
output;
end;
data p96s (keep=site poc p96s);
set temp4; by site poc v;
if first.poc then n=0;
if w gt .96 then n+1;
if n=1 then do; 
p96s=v;
output;
end;
data p97s (keep=site poc p97s);
set temp4; by site poc v;
if first.poc then n=0;
if w gt .97 then n+1;
if n=1 then do; 
p97s=v;
output;
end;
data p98s (keep=site poc p98s);
set temp4; by site poc v;
if first.poc then n=0;
if w gt .98 then n+1;
if n=1 then do; 
p98s=v;
output;
end;
data p99s (keep=site poc p99s);
set temp4; by site poc v;
if first.poc then n=0;
if w gt .99 then n+1;
if n=1 then do; 
p99s=v;
output;
end;

run;

*merge annual stats;
data final&runyr; 
array p(4) p&runyr.q1-p&runyr.q4;
merge q1 q2 q3 q4 t1 t2 t3 t4 t1A t2A t3A t4A p95 p96 p97 p99 p98 
p95s p96s p97s p98s p99s; by site poc;
state=fipname(substr(site,1,2));
do i=1 to 4;
 p(i)=round(p(i),.01);
end;
*p98s=.;
if p98s ne . then do;
 p95_&runyr=p95s;
  p96_&runyr=p96s;
   p97_&runyr=p97s;
    p98_&runyr=p98s; 
p99_&runyr=p99s;

sea&runyr=1;
end;
mean_&runyr=mean(of mean&runyr.q1-mean&runyr.q4);
drop n mean q _freq_ _type_ nc an i; 


proc sort; by site poc;

run;
%end;

%let y2 =%eval(&styear+1);

*Merge 3 year stats;
data &lib..peaksPM25dv_&styear&endyear.B;
retain
site poc sea&styear sea&y2 sea&endyear state
sf&styear.q1-sf&styear.q4 sf&y2.q1-sf&y2.q4 sf&endyear.q1-sf&endyear.q4 
nvalid&styear.q1-nvalid&styear.q4 nvalid&y2.q1-nvalid&y2.q4 nvalid&endyear.q1-nvalid&endyear.q4
n&styear.q1-n&styear.q4 n&y2.q1-n&y2.q4 n&endyear.q1-n&endyear.q4
p&styear.q1-p&styear.q4 p&y2.q1-p&y2.q4 p&endyear.q1-p&endyear.q4
mean&styear.q1-mean&styear.q4 mean&y2.q1-mean&y2.q4 mean&endyear.q1-mean&endyear.q4
mean_&styear-mean_&endyear dv_mean
p98_&styear-p98_&endyear dv_p98;
array nobs(12) n&styear.q1-n&styear.q4 n&y2.q1-n&y2.q4 n&endyear.q1-n&endyear.q4;
array p(12) p&styear.q1-p&styear.q4 p&y2.q1-p&y2.q4 p&endyear.q1-p&endyear.q4;
merge final&styear final&y2 final&endyear meta;
by site poc;
format mon_begin mon_end mmddyy10.;
/*dvnf_mean=round(mean(of mean_&styear-mean_&endyear),.1);
dvnf_p98=round(mean(of p98_&styear-p98_&endyear),1);
dvnf_p96=round(mean(of p96_&styear-p96_&endyear),1);
dvnf_p97=round(mean(of p97_&styear-p97_&endyear),1);
dvnf_p99=round(mean(of p99_&styear-p99_&endyear),1);
dvnf_p95=round(mean(of p95_&styear-p95_&endyear),1);
if dvNF_mean ne .;*/
dv_mean=round(mean(of mean_&styear-mean_&endyear),.1);
dv_p98=round(mean(of p98_&styear-p98_&endyear),1);
dv_p96=round(mean(of p96_&styear-p96_&endyear),1);
dv_p97=round(mean(of p97_&styear-p97_&endyear),1);
dv_p99=round(mean(of p99_&styear-p99_&endyear),1);
dv_p95=round(mean(of p95_&styear-p95_&endyear),1);

IF DV_MEAN NE .; 

nuq_75p=0;
numq_n11=0;
do i=1 to 12;
if p(i) ge .75 then numq_75p+1;
if nobs(i) ge 11 then numq_n11+1;
end;
drop i;
if dv_mean le 15.0 and numq_75p=12 then do; compnaaqs_annual=1; compnaaqs_daily=1; end;
if dv_mean gt 15.0 and numq_n11=12 then do; compnaaqs_annual=1; compnaaqs_daily=1; end;
if dv_p98 gt 65 and n(of n&styear.q1-n&styear.q4) ge 1 and n(of n&y2.q1-n&y2.q4) ge 1
and n(of n&endyear.q1-n&endyear.q4) ge 1 then compnaaqs_daily=1;

nall01=sum(of n2001q1-n2001q4);
nall02=sum(of n2002q1-n2002q4);
nall03=sum(of n2003q1-n2003q4);
nvalid01=sum(of nvalid2001q1-nvalid2001q4);
nvalid02=sum(of nvalid2002q1-nvalid2002q4);
nvalid03=sum(of nvalid2003q1-nvalid2003q4);
run;

%end;

%else %put ****INVALID YEARS******;

%mend;

libname staff 'D:\PM NAAQS\summer04';
%pmfine(staff,2001,2003,y,v,sme,elialexkris6);run;
